"use strict";
/*
Copyright 2016 OpenMarket Ltd

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildMenuTemplate = buildMenuTemplate;
const electron_1 = require("electron");
const language_helper_1 = require("./language-helper");
const isMac = process.platform === "darwin";
function buildMenuTemplate() {
    var _a;
    // Menu template from http://electron.atom.io/docs/api/menu/, edited
    const template = [
        {
            label: (0, language_helper_1._t)("action|edit"),
            accelerator: "e",
            submenu: [
                {
                    role: "undo",
                    label: (0, language_helper_1._t)("action|undo"),
                },
                {
                    role: "redo",
                    label: (0, language_helper_1._t)("action|redo"),
                },
                { type: "separator" },
                {
                    role: "cut",
                    label: (0, language_helper_1._t)("action|cut"),
                },
                {
                    role: "copy",
                    label: (0, language_helper_1._t)("action|copy"),
                },
                {
                    role: "paste",
                    label: (0, language_helper_1._t)("action|paste"),
                },
                {
                    role: "pasteAndMatchStyle",
                    label: (0, language_helper_1._t)("action|paste_match_style"),
                },
                {
                    role: "delete",
                    label: (0, language_helper_1._t)("action|delete"),
                },
                {
                    role: "selectAll",
                    label: (0, language_helper_1._t)("action|select_all"),
                },
            ],
        },
        {
            label: (0, language_helper_1._t)("view_menu|view"),
            accelerator: "V",
            submenu: [
                { type: "separator" },
                {
                    role: "resetZoom",
                    accelerator: "CmdOrCtrl+Num0",
                    visible: false,
                },
                {
                    role: "zoomIn",
                    accelerator: "CmdOrCtrl+NumAdd",
                    visible: false,
                },
                {
                    role: "zoomOut",
                    accelerator: "CmdOrCtrl+NumSub",
                    visible: false,
                },
                {
                    role: "resetZoom",
                    label: (0, language_helper_1._t)("view_menu|actual_size"),
                },
                {
                    role: "zoomIn",
                    label: (0, language_helper_1._t)("action|zoom_in"),
                },
                {
                    role: "zoomOut",
                    label: (0, language_helper_1._t)("action|zoom_out"),
                },
                { type: "separator" },
                // in macOS the Preferences menu item goes in the first menu
                ...(!isMac
                    ? [
                        {
                            label: (0, language_helper_1._t)("common|preferences"),
                            click() {
                                var _a;
                                (_a = global.mainWindow) === null || _a === void 0 ? void 0 : _a.webContents.send("preferences");
                            },
                        },
                    ]
                    : []),
                {
                    role: "togglefullscreen",
                    label: (0, language_helper_1._t)("view_menu|toggle_full_screen"),
                },
                {
                    role: "toggleDevTools",
                    label: (0, language_helper_1._t)("view_menu|toggle_developer_tools"),
                },
            ],
        },
        {
            label: (0, language_helper_1._t)("window_menu|label"),
            accelerator: "w",
            role: "window",
            submenu: [
                {
                    role: "minimize",
                    label: (0, language_helper_1._t)("action|minimise"),
                },
                {
                    role: "close",
                    label: (0, language_helper_1._t)("action|close"),
                },
            ],
        },
        {
            label: (0, language_helper_1._t)("common|help"),
            accelerator: "h",
            role: "help",
            submenu: [
                {
                    // XXX: vectorConfig won't have defaults applied to it so we need to duplicate them here
                    label: (0, language_helper_1._t)("common|brand_help", { brand: ((_a = global.vectorConfig) === null || _a === void 0 ? void 0 : _a.brand) || "Element" }),
                    click() {
                        var _a;
                        void electron_1.shell.openExternal(((_a = global.vectorConfig) === null || _a === void 0 ? void 0 : _a.help_url) || "https://element.io/help");
                    },
                },
            ],
        },
    ];
    // macOS has specific menu conventions...
    if (isMac) {
        template.unshift({
            // first macOS menu is the name of the app
            role: "appMenu",
            label: electron_1.app.name,
            submenu: [
                {
                    role: "about",
                    label: (0, language_helper_1._t)("common|about") + " " + electron_1.app.name,
                },
                { type: "separator" },
                {
                    label: (0, language_helper_1._t)("common|preferences") + "…",
                    accelerator: "Command+,", // Mac-only accelerator
                    click() {
                        var _a;
                        (_a = global.mainWindow) === null || _a === void 0 ? void 0 : _a.webContents.send("preferences");
                    },
                },
                { type: "separator" },
                {
                    role: "services",
                    label: (0, language_helper_1._t)("menu|services"),
                    submenu: [],
                },
                { type: "separator" },
                {
                    role: "hide",
                    label: (0, language_helper_1._t)("menu|hide"),
                },
                {
                    role: "hideOthers",
                    label: (0, language_helper_1._t)("menu|hide_others"),
                },
                {
                    role: "unhide",
                    label: (0, language_helper_1._t)("menu|unhide"),
                },
                { type: "separator" },
                {
                    role: "quit",
                    label: (0, language_helper_1._t)("action|quit"),
                },
            ],
        });
        // Edit menu.
        // This has a 'speech' section on macOS
        template[1].submenu.push({ type: "separator" }, {
            label: (0, language_helper_1._t)("edit_menu|speech"),
            submenu: [
                {
                    role: "startSpeaking",
                    label: (0, language_helper_1._t)("edit_menu|speech_start_speaking"),
                },
                {
                    role: "stopSpeaking",
                    label: (0, language_helper_1._t)("edit_menu|speech_stop_speaking"),
                },
            ],
        });
        // Window menu.
        // This also has specific functionality on macOS
        template[3].submenu = [
            {
                label: (0, language_helper_1._t)("action|close"),
                accelerator: "CmdOrCtrl+W",
                role: "close",
            },
            {
                label: (0, language_helper_1._t)("action|minimise"),
                accelerator: "CmdOrCtrl+M",
                role: "minimize",
            },
            {
                label: (0, language_helper_1._t)("window_menu|zoom"),
                role: "zoom",
            },
            {
                type: "separator",
            },
            {
                label: (0, language_helper_1._t)("window_menu|bring_all_to_front"),
                role: "front",
            },
        ];
    }
    else {
        template.unshift({
            label: (0, language_helper_1._t)("file_menu|label"),
            accelerator: "f",
            submenu: [
                // For some reason, 'about' does not seem to work on windows.
                /*{
                    role: 'about',
                    label: _t('About'),
                },*/
                {
                    role: "quit",
                    label: (0, language_helper_1._t)("action|quit"),
                },
            ],
        });
    }
    return electron_1.Menu.buildFromTemplate(template);
}
